
#import <Foundation/Foundation.h>
#import "iCore.h"
#import <CoreMotion/CoreMotion.h>

//~version:2.01
//~dependsOn:MessageUI.framework
//~dependson:CoreMotion.framework
//~ShortName:MessageComposer
//~ObjectWrapper:MFMessageComposeViewController*
//~event:Complete (Result As Int)
@interface B4IMessageComposer:B4IObjectWrapper
//Gets or sets the message body.
@property (nonatomic)NSString *Body;
//Returns true if the device can send text messages.
@property (nonatomic, readonly)BOOL CanSendText;
@property (nonatomic, readonly)int RESULT_CANCELLED;
@property (nonatomic, readonly)int RESULT_SENT;
@property (nonatomic, readonly)int RESULT_FAILED;
- (void)Initialize:(B4I *)bi :(NSString *)EventName;
/**
*Sets the message recipients.
*Example:<code>
*Message.SetRecipients(Array("123456789"))</code>
 */
- (void)SetRecipients:(B4IList *)Recipients;
//Shows the message composer.
- (void)Show:(B4IPage *)Parent;
@end
//~Shortname:Clipboard
@interface B4IClipboard:NSObject
//Gets or sets the last item in the clipboard. Returns an empty string if no string item is available.
@property (nonatomic) NSString *StringItem;
//Gets or sets the last item in the clipboard. Returns an uninitialized Bitmap if no image item is available.
@property (nonatomic) B4IBitmap* ImageItem;
@end

//~ShortName:MailComposer
//~ObjectWrapper:MFMailComposeViewController*
//~event:Complete (Result As Int)
@interface B4IMailComposer:B4IObjectWrapper
@property (nonatomic, readonly)BOOL CanSendMail;
@property (nonatomic, readonly)int RESULT_CANCELLED;
@property (nonatomic, readonly)int RESULT_SENT;
@property (nonatomic, readonly)int RESULT_FAILED;
@property (nonatomic, readonly)int RESULT_SAVED;
//Initializes the object.
- (void)Initialize:(B4I *)bi :(NSString *)EventName;

/**
* Sets the "To" recipients.
* Example:<code>
* Mail.SetToRecipients(Array("hello@example.com"))</code>
*/
- (void)SetToRecipients:(B4IList *)Recipients;
//Similar to SetToRecipients. Sets the "Cc" recipients.
- (void)SetCcRecipients:(B4IList *)Recipients;
//Similar to SetToRecipients. Sets the "Bcc" recipients.
- (void)SetBccRecipients:(B4IList *)Recipients;
//Sets the mail subject.
- (void)SetSubject:(NSString *)Subject;

/**
* Sets the mail body.
*Body - Message text.
*Html - True for Html mail, false for plain text.
*/
- (void)SetBody:(NSString *)Body :(BOOL)Html;

/**
* Adds an attachment to the mail.
*MimeType - The attachment MIME type. Use application/octet-stream for binary files.
*/
- (void)AddAttachment:(NSString *)Dir :(NSString *)FileName :(NSString *)MimeType;

/**
* Shows the mail composer.
*/
- (void)Show:(B4IPage *)Parent;
@end
/**
* Synthesizes text to speech and plays it.
*/
//~shortname:TTS
//~objectwrapper:AVSpeechSynthesizer*
//~dependson:AVFoundation.framework
//~event:Complete (Text As String)
@interface B4ITTS : B4IObjectWrapper
//Gets or sets the speech rate. The value should be between MIN_SPEECH_RATE to MAX_SPEECH_RATE.
@property (nonatomic) float SpeechRate;
//Gets or sets the pitch value. The value should be between 0.5 to 2.
@property (nonatomic) float Pitch;
@property (nonatomic, readonly) float MAX_SPEECH_RATE;
@property (nonatomic, readonly) float MIN_SPEECH_RATE;
- (void)Initialize:(B4I *)bi :(NSString *)EventName;

/**
* Speaks the given text. The Complete event will be raised after the text is spoken.
* Text - Text to speak.
* ClearQueue - Whether to dismiss all waiting texts.
*/
- (void)Speak:(NSString *)Text :(BOOL)ClearQueue;
//Stops speaking and dismisses texts in the queue.
- (void)Stop;

/**
* Sets the voice language. The language code is made of the language (two lower case letters) and the locale (two upper case
* letters) separated with a dash. You can use GetSupportedLanguages to find all the supported language codes.
* Returns true if the language was set successfully.
*/
- (BOOL)SetLanguage:(NSString *)LanguageCode;
//Returns a list with all the supported language codes.
- (B4IList *)GetSupportedLanguages;

@end
//~shortname:Phone
@interface B4IPhone : NSObject
//Vibrates the device for a short period.
- (void)Vibrate;
/**
* Sets the flash light state. Return true if the operation was successful.
*/
- (BOOL)SetFlashlight:(BOOL)On;

/**
* Adds the given image to the device album.
*/
- (void)AddImageToAlbum:(B4IBitmap *)Image;

/**
* Adds the specified video to the device album. Returns false if the device does not support this feature.
*/
- (BOOL)AddVideoToAlbum:(NSString *)Dir :(NSString *)FileName;
/**
 * Puts a key/value pair in the keychain. These values will be available even if the app is reinstalled.
 */
- (void)KeyChainPut:(NSString *)Key :(NSString *)Value;
/**
 * Gets a stored value from the keychain. Returns an empty string if the key is not found.
 */
- (NSString *)KeyChainGet:(NSString *)Key;
/**
 * Removes a key/value pair from the keychain.
 */
- (void)KeyChainRemove:(NSString *)Key;
@end
/**
* See the settings tutorial for more information.
*/
//~shortname: Settings
@interface B4ISettings:NSObject

- (void)Initialize;
//Gets a Boolean value.
- (BOOL)GetBoolean:(NSString *)Key;
//Gets an Int value.
- (int)GetInt:(NSString *)Key;
//Gets a String value.
- (NSString *)GetString:(NSString *)Key;
//Sets the value of the existing key or adds a new key / value pair.
- (void)Put:(NSString *)Key :(NSObject *)Value;
//Persists the changes.
- (void)Synchronize;
@end
//~shortname: Motion
//~objectwrapper: CMMotionManager*
@interface B4IMotion:B4IObjectWrapper

- (void)Initialize;
//Starts monitoring the motion sensors.
- (void)Start;
//Stops monitoring the motion sensors.
- (void)Stop;
//Starts monitoring the magnetometer sensor.
- (void)StartMagnetometer;
//Stops monitoring the magnetometer sensor.
- (void)StopMagnetometer;

/**
* Returns an array with the raw magnetometer data (x, y and z).
* Returns an empty array if data is not available.
*/
- (B4IArray */*double,1*/)GetMagnetometer;

/**
* Returns an array with the device attitude measured in radians (yaw, pitch and roll).
*/
- (B4IArray */*double,1*/)GetAttitude;

/**
* Returns the device acceleration measured in G units (9.81 m / s^2) not including the earth gravity (x, y and z).
*/
- (B4IArray */*double,1*/)GetUserAcceleration;
@end
//~shortname:DocumentInteraction
//~objectwrapper: UIDocumentInteractionController*
//~event: Closed
//~event:SendingFile
@interface B4IDocumentInteractionWrapper: B4IObjectWrapper
//Gets or sets the file type.
@property (nonatomic)NSString *UTI;

/**
* Initializes the controller and sets the file that should be opened.
*/
- (void)Initialize:(B4I *)bi :(NSString *)EventName :(NSString *)Dir :(NSString *)FileName;

/**
*Shows the dialog. FromView should be a View or BarButton. The dialog will be anchored to this view (on iPad).
*Returns False if there is no app that can open the file.
 */
- (BOOL)OpenFile:(NSObject *)FromView;
/**
 * Opens a file preview. The preview will also include options such as printing the document.
 *Returns False if the file type is not supported.
 *The following types of documents are supported: iWord, Microsoft Office, RTF, PDF, images, text files and CSV files.
 */
- (BOOL)PreviewFile:(B4IPage *)ParentPage;
@end
/**
 * ActivityViewController is a controller that allows the user to share an item from the current app using a third party app (or built-in feature).
 */
//~shortname: ActivityViewController
//~ObjectWrapper: UIActivityViewController
//~Event: Complete (Success As Boolean, ActivityType As String)
@interface B4IActivityViewController : B4IObjectWrapper
/**
 * Initializes the controller and sets the items that will be shared.
 *EventName - Sets the sub that will handle the complete event.
 *Items - One or more items that will be shared.
 */
- (void)Initialize:(B4I *)bi :(NSString *)EventName :(B4IList *)Items;
/**
 * Shows the share dialog.
 *Page - The dialog parent.
 *FromView - Relevant for iPads only. The arrow of the popup dialog will point to the specified view or BarButton.
 */
- (void)Show:(B4IPage *)Page :(NSObject *)FromView;
@end
